==> tgbot-0.30.dev11.tar.gz: tgbot-0.30.dev11/tgbot/basicapi/parser/__init__.py <==
# -*- coding: utf-8 -*-
__author__ = 'Thomas'

import re

from tgbot.basicapi.commands import sendreply
from tgbot.basicapi.parser import commandparser
from tgbot.basicapi.parser import textparser,inlineparser
from tgbot.resources import emoji
from tgbot.tgredis import *
from tgbot import config
wartungsmodus = False
regex = re.compile(r'/(?P<command>\w+)(\s(?P<parameter>.+))?')
data = config

def isadmin(message):
        user = message.from_User
        if str(user.chat_id) in data.get("basics", "superadmins"):
            logger.debug("@" + user.username + "(" + str(user.chat_id) + ") ist ein SuperAdmin.")
            return True
        else:
            logger.debug("@" + user.username + "(" + str(user.chat_id) + ") ist kein SuperAdmin")
            return False

def parsemessage(message,wartungsmodus,args):
    user = message.from_User
    # parsereplycommand(message)
    if message.text is not None:
        #WARTUNGSMODUS
        if wartungsmodus and not isadmin(message):
            sendreply(message, message.chat_id(), emoji.warning + "ICH WERDE GERADE GEWARTET!")
            return
        #WARTUNGSMODUS ENDE
        if re.match(r'/(\w)+', message.text):
                commandparser.parsecommand(message,args)
        elif TGRedis.getconvcommand(message):
                commandparser.parsecommand(message,args)
        else:
            textparser.parsetext(message)


def parseinline(inline,args):
    # parsereplycommand(message)
    if inline.query is not None:
            inlineparser.parseinline(inline,args)

==> tgbot-0.32.dev4.tar.gz: tgbot-0.32.dev4/tgbot/basicapi/parser/__init__.py <==
# -*- coding: utf-8 -*-
__author__ = 'Thomas'

import re

from tgbot.basicapi.commands import sendreply
from tgbot.basicapi.parser import commandparser
from tgbot.basicapi.parser import textparser,inlineparser
from tgbot.resources import emoji
from tgbot.tgredis import *
from tgbot import config
regex = re.compile(r'/(?P<command>\w+)(\s(?P<parameter>.+))?')
data = config

def isadmin(message):
        user = message.from_User
        if str(user.chat_id) in data.get("basics", "superadmins"):
            logger.debug("@" + user.username + "(" + str(user.chat_id) + ") ist ein SuperAdmin.")
            return True
        else:
            logger.debug("@" + user.username + "(" + str(user.chat_id) + ") ist kein SuperAdmin")
            return False

def parsemessage(message,args,wartungsmodus):
    user = message.from_User
    # parsereplycommand(message)
    if message.text is not None:
        #WARTUNGSMODUS
        if wartungsmodus and not isadmin(message):
            sendreply(message, message.chat_id(), emoji.warning + "ICH WERDE GERADE GEWARTET!")
            return
        #WARTUNGSMODUS ENDE
        if re.match(r'/(\w)+', message.text):
                commandparser.parsecommand(message,args)
        elif TGRedis.getconvcommand(message):
                commandparser.parsecommand(message,args)
        else:
            textparser.parsetext(message)


def parseinline(inline,args):
    # parsereplycommand(message)
    if inline.query is not None:
            inlineparser.parseinline(inline,args)
